<h1 align="center">
rgmol v0.1.4.1
</h1>

rgmol is a python package that intends to offer calculations and visualizations of molecular properties.
Its main purpose is to compute and visualize the condensed and non-condensed linear response function from CDFT.

- **Github :** https://github.com/re-gr/rgmol
- **Documentation :** https://re-gr.github.io/rgmol_wiki/

Installation :

	pip install rgmol

## Getting Started

An example script can be found in "rgmol/example_script.py"

A detailed tutorial can be found in the documentation.

## Depedencies

	numpy
	scipy
   	periodictable
	pyvista
	matplotlib

## Contact

Email : [Rg](mailto:remi.grincourt@ens-lyon.fr)


